@@ -121,7 +121,7 @@ void GreeterWindow::initUI()
     //电源对话框打开按钮
     m_powerLB = new QPushButton(this);
     m_powerLB->setObjectName(QStringLiteral("powerButton"));
-    m_powerLB->setIcon(QPixmap(":/resource/power.png"));
+    m_powerLB->setIcon(QPixmap(":/images/power.png"));
     m_powerLB->setIconSize(QSize(39, 39));
     m_powerLB->setFocusPolicy(Qt::NoFocus);
     m_powerLB->setFixedSize(48, 48);
@@ -132,7 +132,7 @@ void GreeterWindow::initUI()
     //虚拟键盘启动按钮
     m_keyboardLB = new QPushButton(this);
     m_keyboardLB->setObjectName(QStringLiteral("keyboardButton"));
-    m_keyboardLB->setIcon(QPixmap(":/resource/keyboard.png"));
+    m_keyboardLB->setIcon(QPixmap(":/images/keyboard.png"));
     m_keyboardLB->setIconSize(QSize(30, 30));
     m_keyboardLB->setFocusPolicy(Qt::NoFocus);
     m_keyboardLB->setFixedSize(48, 48);
@@ -146,12 +146,12 @@ void GreeterWindow::initUI()
     {
         m_sessionLB = new QPushButton(this);
         m_sessionLB->setObjectName((QStringLiteral("sessionButton")));
-        m_sessionLB->setIconSize(QSize(39, 39));
+        m_sessionLB->setIconSize(QSize(24, 24));
         m_sessionLB->setFocusPolicy(Qt::NoFocus);
         m_sessionLB->setFixedSize(48, 48);
         m_sessionLB->setCursor(Qt::PointingHandCursor);
         m_sessionLB->installEventFilter(this);
-        m_sessionLB->setIcon(QIcon(IMAGE_DIR + QString("badges/unknown_badge.png")));
+        m_sessionLB->setIcon(QIcon(IMAGE_DIR + QString("badges/unknown_badge.svg")));
         onSessionChanged(m_greeter->defaultSessionHint());
         connect(m_sessionLB, &QPushButton::clicked, this, &GreeterWindow::showSessionWnd);
     }
@@ -163,6 +163,7 @@ void GreeterWindow::initUI()
     m_languageLB->setFont(QFont("Ubuntu", 16));
     m_languageLB->setFixedHeight(48);
     m_languageLB->setCursor(Qt::PointingHandCursor);
+    m_languageLB->installEventFilter(this);
     LanguagesVector defaultLang = getLanguages();
     if(defaultLang.count()>0){
         m_languageLB->setText(defaultLang.at(0).name);
@@ -223,10 +224,13 @@ void GreeterWindow::initUI()
         QString lastLoginUser = Configuration::instance()->getLastLoginUser();
         m_userWnd->setCurrentUser(lastLoginUser);
     }
+
+    setWindowOpacity(0.5);
 }
 
 void GreeterWindow::setUserWindowVisible(bool visible)
 {
+	//对距离进行缩放
     if(m_userWnd)
         m_userWnd->setVisible(visible);
     if(!visible){
@@ -254,7 +258,6 @@ void GreeterWindow::resizeEvent(QResizeEvent *event)
     QSize size = event->size();
     //重新计算缩放比例
     scale = QString::number(size.width() / 1920.0, 'f', 1).toFloat();
-    scale = scale > 0.5 ? scale : (width() >= 800 ? 0.5 : scale);
     
     if(scale > 1)
         scale = 1;
@@ -262,11 +265,13 @@ void GreeterWindow::resizeEvent(QResizeEvent *event)
 
     qDebug() << "GreeterWindow resize to " << size;
     qDebug() << "scale: " << scale;
+//对距离进行缩放
+    widgetTime->move((width()-widgetTime->geometry().width())/2, 59*scale); //距离顶部59*scale的距离
 
     if(m_userWnd){
-        m_userWnd->resize(CENTER_ENTRY_WIDTH*9 - ENTRY_WIDTH*4, CENTER_ENTRY_HEIGHT);
+        m_userWnd->resize(CENTER_ENTRY_WIDTH*9 - ENTRY_WIDTH*4 + 240*scale, CENTER_ENTRY_HEIGHT);
         QRect userRect((width()-m_userWnd->width())/2,
-                       widgetTime->y() + widgetTime->height() + 176*scale,
+                       widgetTime->geometry().bottom() + 176*scale,
                        m_userWnd->width(), m_userWnd->height());
         m_userWnd->setGeometry(userRect);
     }
@@ -284,7 +289,7 @@ void GreeterWindow::resizeEvent(QResizeEvent *event)
         m_languageWnd->move(m_languageLB->x(),m_languageLB->y()+m_languageWnd->height());
     }
 
-    //电源按钮位置
+    //电源按钮位置,根据x，y的值进行计算，初始值为到右下角的距离
 
     int x = 39;
     int y = 66;
@@ -293,22 +298,20 @@ void GreeterWindow::resizeEvent(QResizeEvent *event)
     m_powerLB->move(this->width() - x,height() - y);
 
     //虚拟键盘按钮位置
-    x += (m_keyboardLB->width() + 10);
+    x += (m_keyboardLB->width() + 10); //10为间隔
     m_keyboardLB->move(this->width() - x, height() - y);
 
     //桌面环境选择按钮位置
     if(m_sessionLB)
     {
-        x += (m_sessionLB->width() + 10);
+        x += (m_sessionLB->width() + 10); //10为间隔
         m_sessionLB->move(this->width() - x, height() - y);
     }
 
     //语言选择按钮位置
-    x += (m_languageLB->width() + 10);
+    x += (m_languageLB->width() + 10); //10为间隔
     m_languageLB->move(this->width() - x, height() - y);
 
-    widgetTime->move((width()-widgetTime->geometry().width())/2, 59);
-
     //虚拟键盘位置
     setVirkeyboardPos();
 
@@ -318,6 +321,7 @@ void GreeterWindow::setVirkeyboardPos()
 {
     if(m_virtualKeyboard)
     {
+	    //设置屏幕键盘的高度为窗口高度的三分之一
        m_virtualKeyboard->setGeometry(0,
                                        height() - height()/3,
                                        width(), height()/3);
@@ -327,10 +331,27 @@ void GreeterWindow::setVirkeyboardPos()
 bool GreeterWindow::eventFilter(QObject *obj, QEvent *event)
 {
     if(event->type() == QEvent::MouseButtonPress){
+        if(obj == m_sessionLB || obj == m_languageLB || obj == m_powerLB)
+            return false;
+
         if(m_sessionWnd && m_sessionWnd->isVisible())
-            m_sessionWnd->hide();
+        {
+            m_sessionWnd->close();
+            m_sessionWnd = nullptr;
+            update();
+        }
         if(m_languageWnd && m_languageWnd->isVisible())
-            m_languageWnd->hide();
+        {
+            m_languageWnd->close();
+            m_languageWnd = nullptr;
+            update();
+        }
+        if(m_powerWnd && !m_powerWnd->isHidden()){
+            m_powerWnd->close();
+            m_userWnd->show();
+            m_loginWnd->show();
+            update();
+        }
     }
     return false;
 }
@@ -354,6 +375,9 @@ void GreeterWindow::keyReleaseEvent(QKeyEvent *e)
     case Qt::Key_Escape:
         if(m_powerWnd && !m_powerWnd->isHidden()){
             m_powerWnd->close();
+            m_userWnd->show();
+            m_loginWnd->show();
+            update();
         }
     break;
     }
@@ -381,13 +405,36 @@ QString GreeterWindow::getAccountBackground(uid_t uid)
 
 void GreeterWindow::setBackground(const QModelIndex &index)
 {
-    QString backgroundPath = index.data(QLightDM::UsersModel::BackgroundPathRole).toString();
-    if(backgroundPath.isEmpty())
-    {
-        uid_t uid = index.data(QLightDM::UsersModel::UidRole).toUInt();
-        backgroundPath = getAccountBackground(uid);
+    QString backgroundPath;
+
+    bool useUserBackground = false;
+	
+    //读取/var/lib/lightdm-date/用户名/ukui-greeter.conf,
+    //判断是否设置了该用户的登陆界面的背景图片.
+    QString userConfigurePath = m_greeter->getEnsureShareDir(index.data(QLightDM::UsersModel::NameRole).toString()) + "/ukui-greeter.conf";
+    QFile backgroundFile(userConfigurePath);
+    if(backgroundFile.exists()){
+        QSettings settings(userConfigurePath,QSettings::IniFormat);
+        settings.beginGroup("greeter");
+        if(settings.contains("backgroundPath")){
+            QString filepath = settings.value("backgroundPath").toString();
+            if(!filepath.isEmpty() && isPicture(filepath)){
+                backgroundPath = filepath;
+                useUserBackground = true;
+            }
+        }
+        settings.endGroup();
+    }
+
+    if(!useUserBackground){
+        backgroundPath = index.data(QLightDM::UsersModel::BackgroundPathRole).toString();
         if(backgroundPath.isEmpty())
-            backgroundPath = "/usr/share/backgrounds/warty-final-ubuntukylin.jpg";
+        {
+            uid_t uid = index.data(QLightDM::UsersModel::UidRole).toUInt();
+            backgroundPath = getAccountBackground(uid);
+            if(backgroundPath.isEmpty())
+                backgroundPath = m_configuration->getDefaultBackgroundName();
+        }
     }
     QSharedPointer<Background> background(new Background);
     background->type = BACKGROUND_IMAGE;
@@ -476,10 +523,14 @@ void GreeterWindow::onUserChangedByManual(const QString &userName)
     updateSession(userName);
 }
 
-void GreeterWindow::setWindowVisible(bool visible)
+void GreeterWindow::setWindowVisible()
 {
-    m_loginWnd->setVisible(!visible);
-    m_userWnd->setVisible(!visible);
+    if(m_powerWnd && m_powerWnd->isVisible())
+        m_powerWnd->hide();
+
+    m_loginWnd->setVisible(true);
+    m_userWnd->setVisible(true);
+    update();
 }
 /**
  * @brief GreeterWindow::showPowerWnd
@@ -487,26 +538,31 @@ void GreeterWindow::setWindowVisible(bool visible)
  */
 void GreeterWindow::showPowerWnd()
 {
-    m_userWnd->hide();
-        m_loginWnd->hide();
-        //如果已经打开了电源对话框则关闭
-        if(m_powerWnd && !m_powerWnd->isHidden()){
-            m_powerWnd->close();
-            return;
-        }
-        //判断是否已经有用户登录
-        bool hasOpenSessions = false;
-        for(int i = 0; i < m_usersModel->rowCount(); i++) {
-            hasOpenSessions = m_usersModel->index(i, 0).data(QLightDM::UsersModel::LoggedInRole).toBool();
-            if(hasOpenSessions)
-                break;
-        }
-        m_powerWnd = new PowerWindow(hasOpenSessions, this);
-        connect(m_powerWnd, &PowerWindow::windowVisibleChanged,
-                    this, &GreeterWindow::setWindowVisible);
+    //如果已经打开了电源对话框则关闭
+    if(m_powerWnd && !m_powerWnd->isHidden()){
+        m_powerWnd->close();
+        m_userWnd->show();
+        m_loginWnd->show();
+        update();
+        return;
+    }
 
-        m_powerWnd->setObjectName(QStringLiteral("powerWnd"));
-        m_powerWnd->show();
+    m_userWnd->hide();
+    m_loginWnd->hide();
+
+    m_powerWnd = new PowerManager(this);
+    m_powerWnd->adjustSize();
+//    m_powerWnd->setGeometry((width()-ITEM_WIDTH*5)/2,
+//                              (height()-ITEM_HEIGHT)/2,
+//                              ITEM_WIDTH*5,ITEM_HEIGHT);
+    m_powerWnd->setFixedSize(m_powerWnd->windowSize());
+    m_powerWnd->move((width()-m_powerWnd->width())/2,(height() - m_powerWnd->height())/2);
+
+    connect(m_powerWnd,SIGNAL(switchToUser())
+            ,this,SLOT(setWindowVisible()));
+    m_powerWnd->setObjectName(QStringLiteral("powerWnd"));
+    m_powerWnd->show();
+    update();
 }
 
 /**
@@ -558,15 +614,16 @@ void GreeterWindow::showLanguageWnd()
     }
     m_languageHasChanged = true;
     if(m_languageWnd->isVisible()){
-        m_languageWnd->hide();
+        m_languageWnd->close();
+        m_languageWnd = nullptr;
         setFocus();
     }
     else{
         m_languageWnd->show();
         m_languageWnd->setFocus();
-        m_languageWnd->setCurrentLanguage(m_greeter->lang());
-        m_languageWnd->move(m_languageLB->x(),m_languageLB->y()-m_languageWnd->height() - 5);
+        m_languageWnd->move(m_languageLB->x(),m_languageLB->y()-m_languageWnd->height() - 3);
     }
+    update();
 }
 
 void GreeterWindow::setWindowPos(QWidget *widget, Qt::Alignment align)
@@ -606,7 +663,8 @@ void GreeterWindow::onLanguageChanged(const Language &language)
     const QFont &font = m_languageLB->font();
     QFontMetrics fm(font);
     int pixelWidth = fm.width(language.name);
-    m_languageLB->setFixedWidth(pixelWidth + 4);
+//根据语言文字的长度计算按钮的宽度，并加上文字距离按钮两边的间距
+    m_languageLB->setFixedWidth(pixelWidth + 14);
 
     int x,y;
     if(m_sessionLB)
@@ -619,19 +677,30 @@ void GreeterWindow::onLanguageChanged(const Language &language)
         x = m_keyboardLB->geometry().left();
         y = m_keyboardLB->y();
     }
-
+//10为距离左边按钮的距离
     m_languageLB->move(x - 10 - m_languageLB->width() , y);
 
     if(m_userWnd && !m_userWnd->isHidden())
     {
         m_userWnd->setFocus();
     }
+    if(m_languageWnd){
+        m_languageWnd->close();
+        m_languageWnd = nullptr;
+    }
 }
 
 void GreeterWindow::showSessionWnd()
 {
     if(!m_sessionWnd){
         m_sessionWnd = new SessionWindow(m_sessionsModel, this);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 7, 0))
+        m_sessionWnd->setStyleSheet("QMenu::item{padding: 2px 10px 2px 10px;}");
+#else
+        m_sessionWnd->setStyleSheet("QMenu::item{padding: 2px 10px 2px 30px;}");
+#endif
+
         connect(m_sessionWnd, &SessionWindow::sessionChanged, \
                 this, &GreeterWindow::onSessionChanged);
     }
@@ -639,15 +708,16 @@ void GreeterWindow::showSessionWnd()
     m_sessionHasChanged = true;
 
     if(m_sessionWnd->isVisible()){
-        m_sessionWnd->hide();
+        m_sessionWnd->close();
+        m_sessionWnd = nullptr;
         setFocus();
     }
     else{
-        m_sessionWnd->move(m_languageLB->x(),m_languageLB->y()-m_sessionWnd->height());
+        m_sessionWnd->move(m_languageLB->x(),m_languageLB->y()-m_sessionWnd->height() - 3);
         m_sessionWnd->show();
-        m_sessionWnd->setCurrentSession(m_greeter->session());
         m_sessionWnd->setFocus();
     }
+    update();
 }
 
 void GreeterWindow::onSessionChanged(const QString &session)
@@ -676,11 +746,11 @@ void GreeterWindow::onSessionChanged(const QString &session)
     }
 
     QString sessionPrefix = sessionTmp.left(sessionTmp.indexOf('-'));
-    QString sessionIcon = IMAGE_DIR + QString("badges/%1_badge.png")
+    QString sessionIcon = IMAGE_DIR + QString("badges/%1_badge.svg")
             .arg(sessionPrefix.toLower());
     QFile iconFile(sessionIcon);
     if(!iconFile.exists()){
-        sessionIcon = IMAGE_DIR + QString("badges/unknown_badge.png");
+        sessionIcon = IMAGE_DIR + QString("badges/unknown_badge.svg");
     }
     qDebug() << sessionIcon;
 
@@ -693,6 +763,11 @@ void GreeterWindow::onSessionChanged(const QString &session)
     {
         m_userWnd->setFocus();
     }
+
+    if(m_sessionWnd){
+        m_sessionWnd->close();
+        m_sessionWnd = nullptr;
+    }
 }
 
 bool GreeterWindow::sessionIsValid(const QString &session)
