@@ -25,6 +25,7 @@
 #include <QGridLayout>
 #include <QAbstractItemModel>
 #include <QPainter>
+#include <QPainterPath>
 
 #include "greeterwrapper.h"
 #include "iconedit.h"
@@ -114,7 +115,7 @@ void LoginWindow::initUI()
     /* 密码框 */
     m_passwordEdit = new IconEdit(m_passwdWidget);
     m_passwordEdit->setObjectName(QStringLiteral("passwordEdit"));   
-    m_passwordEdit->setIcon(QIcon(":/resource/login-button.png"));
+    m_passwordEdit->setIcon(QIcon(":/images/login-button.png"));
     m_passwordEdit->setFocusPolicy(Qt::StrongFocus);
     m_passwordEdit->installEventFilter(this);
     m_passwordEdit->hide(); //收到请求密码的prompt才显示出来
@@ -196,6 +197,9 @@ void LoginWindow::setChildrenGeometry()
 
     // 密码框和提示信息显示位置
 
+    if(scale < 0.5)
+        setFixedWidth(300);
+
     m_passwdWidget->setGeometry(0, 0, width(), 150);
     m_passwordEdit->setGeometry((m_passwdWidget->width() - 300)/2, 0, 300, 34);
     m_messageLabel->setGeometry((m_passwdWidget->width() - 600)/2,
@@ -291,7 +295,7 @@ void LoginWindow::setFace(const QString& facePath)
     if(faceFile.exists())
         faceImage = scaledPixmap(128, 128, facePath);
     else
-        faceImage = scaledPixmap(128, 128, ":/resource/default_face.png");
+        faceImage = scaledPixmap(128, 128, ":/images/default_face.png");
 
     faceImage =  PixmapToRound(faceImage,62);
     m_faceLabel->setAlignment(Qt::AlignCenter);
@@ -747,7 +751,7 @@ void LoginWindow::initBiometricButtonWidget()
 
     m_biometricButton = new QPushButton(m_buttonsWidget);
     m_biometricButton->setObjectName(QStringLiteral("biometricButton"));
-    m_biometricButton->setIcon(QIcon(":/resource/bio-login.png"));
+    m_biometricButton->setIcon(QIcon(":/images/bio-login.png"));
     m_biometricButton->setText(tr("Biometric Authentication"));
     m_biometricButton->setSizePolicy(sizePolicy);
     m_biometricButton->setVisible(false);
@@ -760,7 +764,7 @@ void LoginWindow::initBiometricButtonWidget()
 
     m_passwordButton = new QPushButton(m_buttonsWidget);
     m_passwordButton->setObjectName(QStringLiteral("passwordButton"));
-    m_passwordButton->setIcon(QIcon(":/resource/password-login.png"));
+    m_passwordButton->setIcon(QIcon(":/images/password-login.png"));
     m_passwordButton->setText(tr("Password Authentication"));
     fm = QFontMetrics(m_passwordButton->font(), m_passwordButton);
     width = fm.width(m_passwordButton->text());
@@ -873,24 +877,24 @@ void LoginWindow::onBiometricButtonClicked()
     //当前没有设备，让用户选择设备
     if(!m_deviceInfo)
     {
-        if(m_deviceCount == 1)
-        {
-            DeviceList deviceList = m_biometricProxy->GetDevList();
-            m_deviceInfo = deviceList.at(0);
-            if(!m_deviceInfo)
-            {
-                m_otherDeviceButton->click();
-            }
-            else
-            {
-                authMode = BIOMETRIC;
-                startAuthentication();
-            }
-        }
-        else
-        {
+//        if(m_deviceCount == 1)
+//        {
+//            DeviceList deviceList = m_biometricProxy->GetDevList();
+//            m_deviceInfo = deviceList.at(0);
+//            if(!m_deviceInfo)
+//            {
+//                m_otherDeviceButton->click();
+//            }
+//            else
+//            {
+//                authMode = BIOMETRIC;
+//                startAuthentication();
+//            }
+//        }
+//        else
+//        {
             m_otherDeviceButton->click();
-        }
+//        }
     }
     else
     {
